/* -*- Mode: Java; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

// e10s
var { EzE10SUtils } = ChromeUtils.importESModule(
  "resource:///modules/EzE10SUtils.sys.mjs"
);

// Devtools
ChromeUtils.defineESModuleGetters(this, {
  BrowserToolboxLauncher: "resource://devtools/client/framework/browser-toolbox/Launcher.sys.mjs",
});

Object.defineProperty(this, "BrowserConsoleManager", {
  get() {
    let { loader } = ChromeUtils.importESModule("resource://devtools/shared/loader/Loader.sys.mjs");
    return loader.require("devtools/client/webconsole/browser-console-manager").BrowserConsoleManager;
  },
  configurable: true,
  enumerable: true,
});

// Main functions
var gWebRunner = {
  homepage: "https://thereisonlyxul.org/",
  toContent: function(aURL) {
    var browser = document.getElementById("main-browser");
    EzE10SUtils.loadURI(browser, aURL);
  },
  toChrome: function(inType, uri, features, args) {
    var topWindow = Services.wm.getMostRecentWindow(inType);

    if (topWindow) {
      topWindow.focus();
    } else if (features) {
      Services.ww.openWindow(null, uri, "_blank", features, args);
    } else {
      Services.ww.openWindow(
        null,
        uri,
        "_blank",
        "chrome,all,dialog=no,extrachrome,menubar,resizable,scrollbars," +
        "status,location,toolbar,personalbar",
        args
      );
    }
  },
  navHome: function() {
    var browser = document.getElementById("main-browser");
    EzE10SUtils.loadURI(browser, this.homepage);
  },
  navigation: function(aNaviCmd) {
    var browser = document.getElementById("main-browser");
    switch (aNaviCmd) {
      case 'back':
        browser.goBack();
        break;
      case 'forward':
        browser.goForward();
        break;
      case 'reload':
        browser.reload();
        break;
      case 'stop':
        browser.stop();
        break;
      default:
        gWebRunner.navHome();
    }
  },
  devtools: function() { BrowserToolboxLauncher.init(); },
  quitApp: function() { Services.startup.quit(Services.startup.eAttemptQuit); },
  startup: function() {
    var browser = document.getElementById("main-browser");
    EzE10SUtils.loadAboutBlank(browser);
    gWebRunner.navHome();
  },
}

// Devtools Compat
function openWebLinkIn(url, where, params) {
  gWebRunner.toContent(url);
}
